# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/logging/v2/logging.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import monitored_resource_pb2 as google_dot_api_dot_monitored__resource__pb2
from google.logging.v2 import log_entry_pb2 as google_dot_logging_dot_v2_dot_log__entry__pb2
from google.logging.v2 import logging_config_pb2 as google_dot_logging_dot_v2_dot_logging__config__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/logging/v2/logging.proto',
  package='google.logging.v2',
  syntax='proto3',
  serialized_options=b'\n\025com.google.logging.v2B\014LoggingProtoP\001Z8google.golang.org/genproto/googleapis/logging/v2;logging\370\001\001\252\002\027Google.Cloud.Logging.V2\312\002\027Google\\Cloud\\Logging\\V2',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fgoogle/logging/v2/logging.proto\x12\x11google.logging.v2\x1a#google/api/monitored_resource.proto\x1a!google/logging/v2/log_entry.proto\x1a&google/logging/v2/logging_config.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\"$\n\x10\x44\x65leteLogRequest\x12\x10\n\x08log_name\x18\x01 \x01(\t\"\xa9\x02\n\x16WriteLogEntriesRequest\x12\x10\n\x08log_name\x18\x01 \x01(\t\x12/\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.google.api.MonitoredResource\x12\x45\n\x06labels\x18\x03 \x03(\x0b\x32\x35.google.logging.v2.WriteLogEntriesRequest.LabelsEntry\x12,\n\x07\x65ntries\x18\x04 \x03(\x0b\x32\x1b.google.logging.v2.LogEntry\x12\x17\n\x0fpartial_success\x18\x05 \x01(\x08\x12\x0f\n\x07\x64ry_run\x18\x06 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x19\n\x17WriteLogEntriesResponse\"\xc8\x01\n\x1cWriteLogEntriesPartialErrors\x12]\n\x10log_entry_errors\x18\x01 \x03(\x0b\x32\x43.google.logging.v2.WriteLogEntriesPartialErrors.LogEntryErrorsEntry\x1aI\n\x13LogEntryErrorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status:\x02\x38\x01\"\x91\x01\n\x15ListLogEntriesRequest\x12\x17\n\x0bproject_ids\x18\x01 \x03(\tB\x02\x18\x01\x12\x16\n\x0eresource_names\x18\x08 \x03(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x10\n\x08order_by\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x05 \x01(\t\"_\n\x16ListLogEntriesResponse\x12,\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.google.logging.v2.LogEntry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\'ListMonitoredResourceDescriptorsRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x12\n\npage_token\x18\x02 \x01(\t\"\x8a\x01\n(ListMonitoredResourceDescriptorsResponse\x12\x45\n\x14resource_descriptors\x18\x01 \x03(\x0b\x32\'.google.api.MonitoredResourceDescriptor\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"H\n\x0fListLogsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\">\n\x10ListLogsResponse\x12\x11\n\tlog_names\x18\x03 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x85\n\n\x10LoggingServiceV2\x12\x88\x02\n\tDeleteLog\x12#.google.logging.v2.DeleteLogRequest\x1a\x16.google.protobuf.Empty\"\xbd\x01\x82\xd3\xe4\x93\x02\xb6\x01* /v2/{log_name=projects/*/logs/*}Z\x1b*\x19/v2/{log_name=*/*/logs/*}Z\'*%/v2/{log_name=organizations/*/logs/*}Z!*\x1f/v2/{log_name=folders/*/logs/*}Z)*\'/v2/{log_name=billingAccounts/*/logs/*}\x12\x86\x01\n\x0fWriteLogEntries\x12).google.logging.v2.WriteLogEntriesRequest\x1a*.google.logging.v2.WriteLogEntriesResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v2/entries:write:\x01*\x12\x82\x01\n\x0eListLogEntries\x12(.google.logging.v2.ListLogEntriesRequest\x1a).google.logging.v2.ListLogEntriesResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v2/entries:list:\x01*\x12\xc5\x01\n ListMonitoredResourceDescriptors\x12:.google.logging.v2.ListMonitoredResourceDescriptorsRequest\x1a;.google.logging.v2.ListMonitoredResourceDescriptorsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v2/monitoredResourceDescriptors\x12\xff\x01\n\x08ListLogs\x12\".google.logging.v2.ListLogsRequest\x1a#.google.logging.v2.ListLogsResponse\"\xa9\x01\x82\xd3\xe4\x93\x02\xa2\x01\x12\x15/v2/{parent=*/*}/logsZ\x1e\x12\x1c/v2/{parent=projects/*}/logsZ#\x12!/v2/{parent=organizations/*}/logsZ\x1d\x12\x1b/v2/{parent=folders/*}/logsZ%\x12#/v2/{parent=billingAccounts/*}/logs\x1a\x8d\x02\xca\x41\x16logging.googleapis.com\xd2\x41\xf0\x01https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read,https://www.googleapis.com/auth/logging.writeB\x98\x01\n\x15\x63om.google.logging.v2B\x0cLoggingProtoP\x01Z8google.golang.org/genproto/googleapis/logging/v2;logging\xf8\x01\x01\xaa\x02\x17Google.Cloud.Logging.V2\xca\x02\x17Google\\Cloud\\Logging\\V2b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_monitored__resource__pb2.DESCRIPTOR,google_dot_logging_dot_v2_dot_log__entry__pb2.DESCRIPTOR,google_dot_logging_dot_v2_dot_logging__config__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_DELETELOGREQUEST = _descriptor.Descriptor(
  name='DeleteLogRequest',
  full_name='google.logging.v2.DeleteLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_name', full_name='google.logging.v2.DeleteLogRequest.log_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=376,
)


_WRITELOGENTRIESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='google.logging.v2.WriteLogEntriesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.logging.v2.WriteLogEntriesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.logging.v2.WriteLogEntriesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=676,
)

_WRITELOGENTRIESREQUEST = _descriptor.Descriptor(
  name='WriteLogEntriesRequest',
  full_name='google.logging.v2.WriteLogEntriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_name', full_name='google.logging.v2.WriteLogEntriesRequest.log_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.logging.v2.WriteLogEntriesRequest.resource', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='google.logging.v2.WriteLogEntriesRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entries', full_name='google.logging.v2.WriteLogEntriesRequest.entries', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partial_success', full_name='google.logging.v2.WriteLogEntriesRequest.partial_success', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dry_run', full_name='google.logging.v2.WriteLogEntriesRequest.dry_run', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WRITELOGENTRIESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=676,
)


_WRITELOGENTRIESRESPONSE = _descriptor.Descriptor(
  name='WriteLogEntriesResponse',
  full_name='google.logging.v2.WriteLogEntriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=703,
)


_WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY = _descriptor.Descriptor(
  name='LogEntryErrorsEntry',
  full_name='google.logging.v2.WriteLogEntriesPartialErrors.LogEntryErrorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.logging.v2.WriteLogEntriesPartialErrors.LogEntryErrorsEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.logging.v2.WriteLogEntriesPartialErrors.LogEntryErrorsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=906,
)

_WRITELOGENTRIESPARTIALERRORS = _descriptor.Descriptor(
  name='WriteLogEntriesPartialErrors',
  full_name='google.logging.v2.WriteLogEntriesPartialErrors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_entry_errors', full_name='google.logging.v2.WriteLogEntriesPartialErrors.log_entry_errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=706,
  serialized_end=906,
)


_LISTLOGENTRIESREQUEST = _descriptor.Descriptor(
  name='ListLogEntriesRequest',
  full_name='google.logging.v2.ListLogEntriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_ids', full_name='google.logging.v2.ListLogEntriesRequest.project_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_names', full_name='google.logging.v2.ListLogEntriesRequest.resource_names', index=1,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='google.logging.v2.ListLogEntriesRequest.filter', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='google.logging.v2.ListLogEntriesRequest.order_by', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.logging.v2.ListLogEntriesRequest.page_size', index=4,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.logging.v2.ListLogEntriesRequest.page_token', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=909,
  serialized_end=1054,
)


_LISTLOGENTRIESRESPONSE = _descriptor.Descriptor(
  name='ListLogEntriesResponse',
  full_name='google.logging.v2.ListLogEntriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='google.logging.v2.ListLogEntriesResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.logging.v2.ListLogEntriesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1056,
  serialized_end=1151,
)


_LISTMONITOREDRESOURCEDESCRIPTORSREQUEST = _descriptor.Descriptor(
  name='ListMonitoredResourceDescriptorsRequest',
  full_name='google.logging.v2.ListMonitoredResourceDescriptorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.logging.v2.ListMonitoredResourceDescriptorsRequest.page_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.logging.v2.ListMonitoredResourceDescriptorsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1153,
  serialized_end=1233,
)


_LISTMONITOREDRESOURCEDESCRIPTORSRESPONSE = _descriptor.Descriptor(
  name='ListMonitoredResourceDescriptorsResponse',
  full_name='google.logging.v2.ListMonitoredResourceDescriptorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_descriptors', full_name='google.logging.v2.ListMonitoredResourceDescriptorsResponse.resource_descriptors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.logging.v2.ListMonitoredResourceDescriptorsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1236,
  serialized_end=1374,
)


_LISTLOGSREQUEST = _descriptor.Descriptor(
  name='ListLogsRequest',
  full_name='google.logging.v2.ListLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='google.logging.v2.ListLogsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.logging.v2.ListLogsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.logging.v2.ListLogsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1376,
  serialized_end=1448,
)


_LISTLOGSRESPONSE = _descriptor.Descriptor(
  name='ListLogsResponse',
  full_name='google.logging.v2.ListLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_names', full_name='google.logging.v2.ListLogsResponse.log_names', index=0,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.logging.v2.ListLogsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1450,
  serialized_end=1512,
)

_WRITELOGENTRIESREQUEST_LABELSENTRY.containing_type = _WRITELOGENTRIESREQUEST
_WRITELOGENTRIESREQUEST.fields_by_name['resource'].message_type = google_dot_api_dot_monitored__resource__pb2._MONITOREDRESOURCE
_WRITELOGENTRIESREQUEST.fields_by_name['labels'].message_type = _WRITELOGENTRIESREQUEST_LABELSENTRY
_WRITELOGENTRIESREQUEST.fields_by_name['entries'].message_type = google_dot_logging_dot_v2_dot_log__entry__pb2._LOGENTRY
_WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY.fields_by_name['value'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY.containing_type = _WRITELOGENTRIESPARTIALERRORS
_WRITELOGENTRIESPARTIALERRORS.fields_by_name['log_entry_errors'].message_type = _WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY
_LISTLOGENTRIESRESPONSE.fields_by_name['entries'].message_type = google_dot_logging_dot_v2_dot_log__entry__pb2._LOGENTRY
_LISTMONITOREDRESOURCEDESCRIPTORSRESPONSE.fields_by_name['resource_descriptors'].message_type = google_dot_api_dot_monitored__resource__pb2._MONITOREDRESOURCEDESCRIPTOR
DESCRIPTOR.message_types_by_name['DeleteLogRequest'] = _DELETELOGREQUEST
DESCRIPTOR.message_types_by_name['WriteLogEntriesRequest'] = _WRITELOGENTRIESREQUEST
DESCRIPTOR.message_types_by_name['WriteLogEntriesResponse'] = _WRITELOGENTRIESRESPONSE
DESCRIPTOR.message_types_by_name['WriteLogEntriesPartialErrors'] = _WRITELOGENTRIESPARTIALERRORS
DESCRIPTOR.message_types_by_name['ListLogEntriesRequest'] = _LISTLOGENTRIESREQUEST
DESCRIPTOR.message_types_by_name['ListLogEntriesResponse'] = _LISTLOGENTRIESRESPONSE
DESCRIPTOR.message_types_by_name['ListMonitoredResourceDescriptorsRequest'] = _LISTMONITOREDRESOURCEDESCRIPTORSREQUEST
DESCRIPTOR.message_types_by_name['ListMonitoredResourceDescriptorsResponse'] = _LISTMONITOREDRESOURCEDESCRIPTORSRESPONSE
DESCRIPTOR.message_types_by_name['ListLogsRequest'] = _LISTLOGSREQUEST
DESCRIPTOR.message_types_by_name['ListLogsResponse'] = _LISTLOGSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeleteLogRequest = _reflection.GeneratedProtocolMessageType('DeleteLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOGREQUEST,
  '__module__' : 'google.logging.v2.logging_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.DeleteLogRequest)
  })
_sym_db.RegisterMessage(DeleteLogRequest)

WriteLogEntriesRequest = _reflection.GeneratedProtocolMessageType('WriteLogEntriesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _WRITELOGENTRIESREQUEST_LABELSENTRY,
    '__module__' : 'google.logging.v2.logging_pb2'
    # @@protoc_insertion_point(class_scope:google.logging.v2.WriteLogEntriesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _WRITELOGENTRIESREQUEST,
  '__module__' : 'google.logging.v2.logging_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.WriteLogEntriesRequest)
  })
_sym_db.RegisterMessage(WriteLogEntriesRequest)
_sym_db.RegisterMessage(WriteLogEntriesRequest.LabelsEntry)

WriteLogEntriesResponse = _reflection.GeneratedProtocolMessageType('WriteLogEntriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _WRITELOGENTRIESRESPONSE,
  '__module__' : 'google.logging.v2.logging_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.WriteLogEntriesResponse)
  })
_sym_db.RegisterMessage(WriteLogEntriesResponse)

WriteLogEntriesPartialErrors = _reflection.GeneratedProtocolMessageType('WriteLogEntriesPartialErrors', (_message.Message,), {

  'LogEntryErrorsEntry' : _reflection.GeneratedProtocolMessageType('LogEntryErrorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY,
    '__module__' : 'google.logging.v2.logging_pb2'
    # @@protoc_insertion_point(class_scope:google.logging.v2.WriteLogEntriesPartialErrors.LogEntryErrorsEntry)
    })
  ,
  'DESCRIPTOR' : _WRITELOGENTRIESPARTIALERRORS,
  '__module__' : 'google.logging.v2.logging_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.WriteLogEntriesPartialErrors)
  })
_sym_db.RegisterMessage(WriteLogEntriesPartialErrors)
_sym_db.RegisterMessage(WriteLogEntriesPartialErrors.LogEntryErrorsEntry)

ListLogEntriesRequest = _reflection.GeneratedProtocolMessageType('ListLogEntriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOGENTRIESREQUEST,
  '__module__' : 'google.logging.v2.logging_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.ListLogEntriesRequest)
  })
_sym_db.RegisterMessage(ListLogEntriesRequest)

ListLogEntriesResponse = _reflection.GeneratedProtocolMessageType('ListLogEntriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOGENTRIESRESPONSE,
  '__module__' : 'google.logging.v2.logging_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.ListLogEntriesResponse)
  })
_sym_db.RegisterMessage(ListLogEntriesResponse)

ListMonitoredResourceDescriptorsRequest = _reflection.GeneratedProtocolMessageType('ListMonitoredResourceDescriptorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMONITOREDRESOURCEDESCRIPTORSREQUEST,
  '__module__' : 'google.logging.v2.logging_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.ListMonitoredResourceDescriptorsRequest)
  })
_sym_db.RegisterMessage(ListMonitoredResourceDescriptorsRequest)

ListMonitoredResourceDescriptorsResponse = _reflection.GeneratedProtocolMessageType('ListMonitoredResourceDescriptorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMONITOREDRESOURCEDESCRIPTORSRESPONSE,
  '__module__' : 'google.logging.v2.logging_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.ListMonitoredResourceDescriptorsResponse)
  })
_sym_db.RegisterMessage(ListMonitoredResourceDescriptorsResponse)

ListLogsRequest = _reflection.GeneratedProtocolMessageType('ListLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOGSREQUEST,
  '__module__' : 'google.logging.v2.logging_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.ListLogsRequest)
  })
_sym_db.RegisterMessage(ListLogsRequest)

ListLogsResponse = _reflection.GeneratedProtocolMessageType('ListLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOGSRESPONSE,
  '__module__' : 'google.logging.v2.logging_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.ListLogsResponse)
  })
_sym_db.RegisterMessage(ListLogsResponse)


DESCRIPTOR._options = None
_WRITELOGENTRIESREQUEST_LABELSENTRY._options = None
_WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY._options = None
_LISTLOGENTRIESREQUEST.fields_by_name['project_ids']._options = None

_LOGGINGSERVICEV2 = _descriptor.ServiceDescriptor(
  name='LoggingServiceV2',
  full_name='google.logging.v2.LoggingServiceV2',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\312A\026logging.googleapis.com\322A\360\001https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read,https://www.googleapis.com/auth/logging.write',
  create_key=_descriptor._internal_create_key,
  serialized_start=1515,
  serialized_end=2800,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeleteLog',
    full_name='google.logging.v2.LoggingServiceV2.DeleteLog',
    index=0,
    containing_service=None,
    input_type=_DELETELOGREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\266\001* /v2/{log_name=projects/*/logs/*}Z\033*\031/v2/{log_name=*/*/logs/*}Z\'*%/v2/{log_name=organizations/*/logs/*}Z!*\037/v2/{log_name=folders/*/logs/*}Z)*\'/v2/{log_name=billingAccounts/*/logs/*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteLogEntries',
    full_name='google.logging.v2.LoggingServiceV2.WriteLogEntries',
    index=1,
    containing_service=None,
    input_type=_WRITELOGENTRIESREQUEST,
    output_type=_WRITELOGENTRIESRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\"\021/v2/entries:write:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLogEntries',
    full_name='google.logging.v2.LoggingServiceV2.ListLogEntries',
    index=2,
    containing_service=None,
    input_type=_LISTLOGENTRIESREQUEST,
    output_type=_LISTLOGENTRIESRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\"\020/v2/entries:list:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMonitoredResourceDescriptors',
    full_name='google.logging.v2.LoggingServiceV2.ListMonitoredResourceDescriptors',
    index=3,
    containing_service=None,
    input_type=_LISTMONITOREDRESOURCEDESCRIPTORSREQUEST,
    output_type=_LISTMONITOREDRESOURCEDESCRIPTORSRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /v2/monitoredResourceDescriptors',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLogs',
    full_name='google.logging.v2.LoggingServiceV2.ListLogs',
    index=4,
    containing_service=None,
    input_type=_LISTLOGSREQUEST,
    output_type=_LISTLOGSRESPONSE,
    serialized_options=b'\202\323\344\223\002\242\001\022\025/v2/{parent=*/*}/logsZ\036\022\034/v2/{parent=projects/*}/logsZ#\022!/v2/{parent=organizations/*}/logsZ\035\022\033/v2/{parent=folders/*}/logsZ%\022#/v2/{parent=billingAccounts/*}/logs',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOGGINGSERVICEV2)

DESCRIPTOR.services_by_name['LoggingServiceV2'] = _LOGGINGSERVICEV2

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/core/v3/resource_locator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from xds.core.v3 import context_params_pb2 as xds_dot_core_dot_v3_dot_context__params__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='xds/core/v3/resource_locator.proto',
  package='xds.core.v3',
  syntax='proto3',
  serialized_options=b'\n\033com.github.udpa.xds.core.v3B\024ResourceLocatorProtoP\001\272\200\310\321\006\002\010\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"xds/core/v3/resource_locator.proto\x12\x0bxds.core.v3\x1a\x1dudpa/annotations/status.proto\x1a xds/core/v3/context_params.proto\x1a\x17validate/validate.proto\"\xc2\x03\n\x0fResourceLocator\x12=\n\x06scheme\x18\x01 \x01(\x0e\x32#.xds.core.v3.ResourceLocator.SchemeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tauthority\x18\x03 \x01(\t\x12\x1e\n\rresource_type\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x33\n\rexact_context\x18\x05 \x01(\x0b\x32\x1a.xds.core.v3.ContextParamsH\x00\x12:\n\ndirectives\x18\x06 \x03(\x0b\x32&.xds.core.v3.ResourceLocator.Directive\x1a|\n\tDirective\x12+\n\x03\x61lt\x18\x01 \x01(\x0b\x32\x1c.xds.core.v3.ResourceLocatorH\x00\x12\x30\n\x05\x65ntry\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x01\x32\x16^[0-9a-zA-Z_\\-\\./~:]+$H\x00\x42\x10\n\tdirective\x12\x03\xf8\x42\x01\"\'\n\x06Scheme\x12\t\n\x05XDSTP\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\x08\n\x04\x46ILE\x10\x02\x42\x19\n\x17\x63ontext_param_specifierB=\n\x1b\x63om.github.udpa.xds.core.v3B\x14ResourceLocatorProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,xds_dot_core_dot_v3_dot_context__params__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_RESOURCELOCATOR_SCHEME = _descriptor.EnumDescriptor(
  name='Scheme',
  full_name='xds.core.v3.ResourceLocator.Scheme',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='XDSTP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=526,
  serialized_end=565,
)
_sym_db.RegisterEnumDescriptor(_RESOURCELOCATOR_SCHEME)


_RESOURCELOCATOR_DIRECTIVE = _descriptor.Descriptor(
  name='Directive',
  full_name='xds.core.v3.ResourceLocator.Directive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alt', full_name='xds.core.v3.ResourceLocator.Directive.alt', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry', full_name='xds.core.v3.ResourceLocator.Directive.entry', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\034r\032\020\0012\026^[0-9a-zA-Z_\\-\\./~:]+$', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='directive', full_name='xds.core.v3.ResourceLocator.Directive.directive',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=400,
  serialized_end=524,
)

_RESOURCELOCATOR = _descriptor.Descriptor(
  name='ResourceLocator',
  full_name='xds.core.v3.ResourceLocator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheme', full_name='xds.core.v3.ResourceLocator.scheme', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='xds.core.v3.ResourceLocator.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority', full_name='xds.core.v3.ResourceLocator.authority', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='xds.core.v3.ResourceLocator.resource_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exact_context', full_name='xds.core.v3.ResourceLocator.exact_context', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='directives', full_name='xds.core.v3.ResourceLocator.directives', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCELOCATOR_DIRECTIVE, ],
  enum_types=[
    _RESOURCELOCATOR_SCHEME,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='context_param_specifier', full_name='xds.core.v3.ResourceLocator.context_param_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=142,
  serialized_end=592,
)

_RESOURCELOCATOR_DIRECTIVE.fields_by_name['alt'].message_type = _RESOURCELOCATOR
_RESOURCELOCATOR_DIRECTIVE.containing_type = _RESOURCELOCATOR
_RESOURCELOCATOR_DIRECTIVE.oneofs_by_name['directive'].fields.append(
  _RESOURCELOCATOR_DIRECTIVE.fields_by_name['alt'])
_RESOURCELOCATOR_DIRECTIVE.fields_by_name['alt'].containing_oneof = _RESOURCELOCATOR_DIRECTIVE.oneofs_by_name['directive']
_RESOURCELOCATOR_DIRECTIVE.oneofs_by_name['directive'].fields.append(
  _RESOURCELOCATOR_DIRECTIVE.fields_by_name['entry'])
_RESOURCELOCATOR_DIRECTIVE.fields_by_name['entry'].containing_oneof = _RESOURCELOCATOR_DIRECTIVE.oneofs_by_name['directive']
_RESOURCELOCATOR.fields_by_name['scheme'].enum_type = _RESOURCELOCATOR_SCHEME
_RESOURCELOCATOR.fields_by_name['exact_context'].message_type = xds_dot_core_dot_v3_dot_context__params__pb2._CONTEXTPARAMS
_RESOURCELOCATOR.fields_by_name['directives'].message_type = _RESOURCELOCATOR_DIRECTIVE
_RESOURCELOCATOR_SCHEME.containing_type = _RESOURCELOCATOR
_RESOURCELOCATOR.oneofs_by_name['context_param_specifier'].fields.append(
  _RESOURCELOCATOR.fields_by_name['exact_context'])
_RESOURCELOCATOR.fields_by_name['exact_context'].containing_oneof = _RESOURCELOCATOR.oneofs_by_name['context_param_specifier']
DESCRIPTOR.message_types_by_name['ResourceLocator'] = _RESOURCELOCATOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResourceLocator = _reflection.GeneratedProtocolMessageType('ResourceLocator', (_message.Message,), {

  'Directive' : _reflection.GeneratedProtocolMessageType('Directive', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCELOCATOR_DIRECTIVE,
    '__module__' : 'xds.core.v3.resource_locator_pb2'
    # @@protoc_insertion_point(class_scope:xds.core.v3.ResourceLocator.Directive)
    })
  ,
  'DESCRIPTOR' : _RESOURCELOCATOR,
  '__module__' : 'xds.core.v3.resource_locator_pb2'
  # @@protoc_insertion_point(class_scope:xds.core.v3.ResourceLocator)
  })
_sym_db.RegisterMessage(ResourceLocator)
_sym_db.RegisterMessage(ResourceLocator.Directive)


DESCRIPTOR._options = None
_RESOURCELOCATOR_DIRECTIVE.oneofs_by_name['directive']._options = None
_RESOURCELOCATOR_DIRECTIVE.fields_by_name['entry']._options = None
_RESOURCELOCATOR.fields_by_name['scheme']._options = None
_RESOURCELOCATOR.fields_by_name['resource_type']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/logging/v2/log_entry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import monitored_resource_pb2 as google_dot_api_dot_monitored__resource__pb2
from google.logging.type import http_request_pb2 as google_dot_logging_dot_type_dot_http__request__pb2
from google.logging.type import log_severity_pb2 as google_dot_logging_dot_type_dot_log__severity__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/logging/v2/log_entry.proto',
  package='google.logging.v2',
  syntax='proto3',
  serialized_options=b'\n\025com.google.logging.v2B\rLogEntryProtoP\001Z8google.golang.org/genproto/googleapis/logging/v2;logging\370\001\001\252\002\027Google.Cloud.Logging.V2\312\002\027Google\\Cloud\\Logging\\V2',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!google/logging/v2/log_entry.proto\x12\x11google.logging.v2\x1a#google/api/monitored_resource.proto\x1a&google/logging/type/http_request.proto\x1a&google/logging/type/log_severity.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\x1a\x1cgoogle/api/annotations.proto\"\x8e\x06\n\x08LogEntry\x12\x10\n\x08log_name\x18\x0c \x01(\t\x12/\n\x08resource\x18\x08 \x01(\x0b\x32\x1d.google.api.MonitoredResource\x12-\n\rproto_payload\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x16\n\x0ctext_payload\x18\x03 \x01(\tH\x00\x12/\n\x0cjson_payload\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12-\n\ttimestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11receive_timestamp\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x08severity\x18\n \x01(\x0e\x32 .google.logging.type.LogSeverity\x12\x11\n\tinsert_id\x18\x04 \x01(\t\x12\x36\n\x0chttp_request\x18\x07 \x01(\x0b\x32 .google.logging.type.HttpRequest\x12\x37\n\x06labels\x18\x0b \x03(\x0b\x32\'.google.logging.v2.LogEntry.LabelsEntry\x12;\n\x08metadata\x18\x19 \x01(\x0b\x32%.google.api.MonitoredResourceMetadataB\x02\x18\x01\x12\x37\n\toperation\x18\x0f \x01(\x0b\x32$.google.logging.v2.LogEntryOperation\x12\r\n\x05trace\x18\x16 \x01(\t\x12\x0f\n\x07span_id\x18\x1b \x01(\t\x12\x15\n\rtrace_sampled\x18\x1e \x01(\x08\x12\x42\n\x0fsource_location\x18\x17 \x01(\x0b\x32).google.logging.v2.LogEntrySourceLocation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07payload\"N\n\x11LogEntryOperation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08producer\x18\x02 \x01(\t\x12\r\n\x05\x66irst\x18\x03 \x01(\x08\x12\x0c\n\x04last\x18\x04 \x01(\x08\"F\n\x16LogEntrySourceLocation\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x0c\n\x04line\x18\x02 \x01(\x03\x12\x10\n\x08\x66unction\x18\x03 \x01(\tB\x99\x01\n\x15\x63om.google.logging.v2B\rLogEntryProtoP\x01Z8google.golang.org/genproto/googleapis/logging/v2;logging\xf8\x01\x01\xaa\x02\x17Google.Cloud.Logging.V2\xca\x02\x17Google\\Cloud\\Logging\\V2b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_monitored__resource__pb2.DESCRIPTOR,google_dot_logging_dot_type_dot_http__request__pb2.DESCRIPTOR,google_dot_logging_dot_type_dot_log__severity__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_LOGENTRY_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='google.logging.v2.LogEntry.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.logging.v2.LogEntry.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.logging.v2.LogEntry.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1045,
  serialized_end=1090,
)

_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='google.logging.v2.LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_name', full_name='google.logging.v2.LogEntry.log_name', index=0,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.logging.v2.LogEntry.resource', index=1,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_payload', full_name='google.logging.v2.LogEntry.proto_payload', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_payload', full_name='google.logging.v2.LogEntry.text_payload', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_payload', full_name='google.logging.v2.LogEntry.json_payload', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='google.logging.v2.LogEntry.timestamp', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive_timestamp', full_name='google.logging.v2.LogEntry.receive_timestamp', index=6,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity', full_name='google.logging.v2.LogEntry.severity', index=7,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insert_id', full_name='google.logging.v2.LogEntry.insert_id', index=8,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_request', full_name='google.logging.v2.LogEntry.http_request', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='google.logging.v2.LogEntry.labels', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='google.logging.v2.LogEntry.metadata', index=11,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='google.logging.v2.LogEntry.operation', index=12,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trace', full_name='google.logging.v2.LogEntry.trace', index=13,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='span_id', full_name='google.logging.v2.LogEntry.span_id', index=14,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trace_sampled', full_name='google.logging.v2.LogEntry.trace_sampled', index=15,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_location', full_name='google.logging.v2.LogEntry.source_location', index=16,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LOGENTRY_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='google.logging.v2.LogEntry.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=319,
  serialized_end=1101,
)


_LOGENTRYOPERATION = _descriptor.Descriptor(
  name='LogEntryOperation',
  full_name='google.logging.v2.LogEntryOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.logging.v2.LogEntryOperation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='producer', full_name='google.logging.v2.LogEntryOperation.producer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first', full_name='google.logging.v2.LogEntryOperation.first', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last', full_name='google.logging.v2.LogEntryOperation.last', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1103,
  serialized_end=1181,
)


_LOGENTRYSOURCELOCATION = _descriptor.Descriptor(
  name='LogEntrySourceLocation',
  full_name='google.logging.v2.LogEntrySourceLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='google.logging.v2.LogEntrySourceLocation.file', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line', full_name='google.logging.v2.LogEntrySourceLocation.line', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='google.logging.v2.LogEntrySourceLocation.function', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1183,
  serialized_end=1253,
)

_LOGENTRY_LABELSENTRY.containing_type = _LOGENTRY
_LOGENTRY.fields_by_name['resource'].message_type = google_dot_api_dot_monitored__resource__pb2._MONITOREDRESOURCE
_LOGENTRY.fields_by_name['proto_payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LOGENTRY.fields_by_name['json_payload'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_LOGENTRY.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGENTRY.fields_by_name['receive_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGENTRY.fields_by_name['severity'].enum_type = google_dot_logging_dot_type_dot_log__severity__pb2._LOGSEVERITY
_LOGENTRY.fields_by_name['http_request'].message_type = google_dot_logging_dot_type_dot_http__request__pb2._HTTPREQUEST
_LOGENTRY.fields_by_name['labels'].message_type = _LOGENTRY_LABELSENTRY
_LOGENTRY.fields_by_name['metadata'].message_type = google_dot_api_dot_monitored__resource__pb2._MONITOREDRESOURCEMETADATA
_LOGENTRY.fields_by_name['operation'].message_type = _LOGENTRYOPERATION
_LOGENTRY.fields_by_name['source_location'].message_type = _LOGENTRYSOURCELOCATION
_LOGENTRY.oneofs_by_name['payload'].fields.append(
  _LOGENTRY.fields_by_name['proto_payload'])
_LOGENTRY.fields_by_name['proto_payload'].containing_oneof = _LOGENTRY.oneofs_by_name['payload']
_LOGENTRY.oneofs_by_name['payload'].fields.append(
  _LOGENTRY.fields_by_name['text_payload'])
_LOGENTRY.fields_by_name['text_payload'].containing_oneof = _LOGENTRY.oneofs_by_name['payload']
_LOGENTRY.oneofs_by_name['payload'].fields.append(
  _LOGENTRY.fields_by_name['json_payload'])
_LOGENTRY.fields_by_name['json_payload'].containing_oneof = _LOGENTRY.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['LogEntry'] = _LOGENTRY
DESCRIPTOR.message_types_by_name['LogEntryOperation'] = _LOGENTRYOPERATION
DESCRIPTOR.message_types_by_name['LogEntrySourceLocation'] = _LOGENTRYSOURCELOCATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogEntry = _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGENTRY_LABELSENTRY,
    '__module__' : 'google.logging.v2.log_entry_pb2'
    # @@protoc_insertion_point(class_scope:google.logging.v2.LogEntry.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LOGENTRY,
  '__module__' : 'google.logging.v2.log_entry_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.LogEntry)
  })
_sym_db.RegisterMessage(LogEntry)
_sym_db.RegisterMessage(LogEntry.LabelsEntry)

LogEntryOperation = _reflection.GeneratedProtocolMessageType('LogEntryOperation', (_message.Message,), {
  'DESCRIPTOR' : _LOGENTRYOPERATION,
  '__module__' : 'google.logging.v2.log_entry_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.LogEntryOperation)
  })
_sym_db.RegisterMessage(LogEntryOperation)

LogEntrySourceLocation = _reflection.GeneratedProtocolMessageType('LogEntrySourceLocation', (_message.Message,), {
  'DESCRIPTOR' : _LOGENTRYSOURCELOCATION,
  '__module__' : 'google.logging.v2.log_entry_pb2'
  # @@protoc_insertion_point(class_scope:google.logging.v2.LogEntrySourceLocation)
  })
_sym_db.RegisterMessage(LogEntrySourceLocation)


DESCRIPTOR._options = None
_LOGENTRY_LABELSENTRY._options = None
_LOGENTRY.fields_by_name['metadata']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/dns/v3/dns_table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/dns/v3/dns_table.proto',
  package='envoy.data.dns.v3',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.data.dns.v3B\rDnsTableProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/data/dns/v3/dns_table.proto\x12\x11\x65nvoy.data.dns.v3\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x86\x0b\n\x08\x44nsTable\x12%\n\x14\x65xternal_retry_count\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x03\x12\x45\n\x0fvirtual_domains\x18\x02 \x03(\x0b\x32,.envoy.data.dns.v3.DnsTable.DnsVirtualDomain\x12<\n\x0eknown_suffixes\x18\x03 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x1a\x62\n\x0b\x41\x64\x64ressList\x12\x1f\n\x07\x61\x64\x64ress\x18\x01 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\x08\x01\"\x04r\x02\x10\x03:2\x9a\xc5\x88\x1e-\n+envoy.data.dns.v2alpha.DnsTable.AddressList\x1a\x64\n\x12\x44nsServiceProtocol\x12\x1a\n\x06number\x18\x01 \x01(\rB\x08\xfa\x42\x05*\x03\x10\xff\x01H\x00\x12\x1a\n\x04name\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01H\x00\x42\x16\n\x0fprotocol_config\x12\x03\xf8\x42\x01\x1a\xbe\x01\n\x10\x44nsServiceTarget\x12\x1f\n\thost_name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01H\x00\x12\"\n\x0c\x63luster_name\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01H\x00\x12\x1b\n\x08priority\x18\x03 \x01(\rB\t\xfa\x42\x06*\x04\x10\x80\x80\x04\x12\x19\n\x06weight\x18\x04 \x01(\rB\t\xfa\x42\x06*\x04\x10\x80\x80\x04\x12\x17\n\x04port\x18\x05 \x01(\rB\t\xfa\x42\x06*\x04\x10\x80\x80\x04\x42\x14\n\rendpoint_type\x12\x03\xf8\x42\x01\x1a\xed\x01\n\nDnsService\x12 \n\x0cservice_name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01\x12@\n\x08protocol\x18\x02 \x01(\x0b\x32..envoy.data.dns.v3.DnsTable.DnsServiceProtocol\x12\x32\n\x03ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x01\x12G\n\x07targets\x18\x04 \x03(\x0b\x32,.envoy.data.dns.v3.DnsTable.DnsServiceTargetB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1aT\n\x0e\x44nsServiceList\x12\x42\n\x08services\x18\x01 \x03(\x0b\x32&.envoy.data.dns.v3.DnsTable.DnsServiceB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xf6\x01\n\x0b\x44nsEndpoint\x12?\n\x0c\x61\x64\x64ress_list\x18\x01 \x01(\x0b\x32\'.envoy.data.dns.v3.DnsTable.AddressListH\x00\x12\x16\n\x0c\x63luster_name\x18\x02 \x01(\tH\x00\x12\x42\n\x0cservice_list\x18\x03 \x01(\x0b\x32*.envoy.data.dns.v3.DnsTable.DnsServiceListH\x00:2\x9a\xc5\x88\x1e-\n+envoy.data.dns.v2alpha.DnsTable.DnsEndpointB\x16\n\x0f\x65ndpoint_config\x12\x03\xf8\x42\x01\x1a\xdb\x01\n\x10\x44nsVirtualDomain\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01\x12\x39\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32\'.envoy.data.dns.v3.DnsTable.DnsEndpoint\x12\x39\n\nanswer_ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x1e:7\x9a\xc5\x88\x1e\x32\n0envoy.data.dns.v2alpha.DnsTable.DnsVirtualDomain:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.data.dns.v2alpha.DnsTableB:\n\x1fio.envoyproxy.envoy.data.dns.v3B\rDnsTableProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_DNSTABLE_ADDRESSLIST = _descriptor.Descriptor(
  name='AddressList',
  full_name='envoy.data.dns.v3.DnsTable.AddressList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.data.dns.v3.DnsTable.AddressList.address', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\222\001\010\010\001\"\004r\002\020\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.data.dns.v2alpha.DnsTable.AddressList',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=498,
)

_DNSTABLE_DNSSERVICEPROTOCOL = _descriptor.Descriptor(
  name='DnsServiceProtocol',
  full_name='envoy.data.dns.v3.DnsTable.DnsServiceProtocol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='number', full_name='envoy.data.dns.v3.DnsTable.DnsServiceProtocol.number', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005*\003\020\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.data.dns.v3.DnsTable.DnsServiceProtocol.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\300\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='protocol_config', full_name='envoy.data.dns.v3.DnsTable.DnsServiceProtocol.protocol_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=500,
  serialized_end=600,
)

_DNSTABLE_DNSSERVICETARGET = _descriptor.Descriptor(
  name='DnsServiceTarget',
  full_name='envoy.data.dns.v3.DnsTable.DnsServiceTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_name', full_name='envoy.data.dns.v3.DnsTable.DnsServiceTarget.host_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\300\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.data.dns.v3.DnsTable.DnsServiceTarget.cluster_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\300\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='envoy.data.dns.v3.DnsTable.DnsServiceTarget.priority', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\020\200\200\004', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='envoy.data.dns.v3.DnsTable.DnsServiceTarget.weight', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\020\200\200\004', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='envoy.data.dns.v3.DnsTable.DnsServiceTarget.port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\020\200\200\004', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='endpoint_type', full_name='envoy.data.dns.v3.DnsTable.DnsServiceTarget.endpoint_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=603,
  serialized_end=793,
)

_DNSTABLE_DNSSERVICE = _descriptor.Descriptor(
  name='DnsService',
  full_name='envoy.data.dns.v3.DnsTable.DnsService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='envoy.data.dns.v3.DnsTable.DnsService.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\300\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='envoy.data.dns.v3.DnsTable.DnsService.protocol', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='envoy.data.dns.v3.DnsTable.DnsService.ttl', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\0042\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targets', full_name='envoy.data.dns.v3.DnsTable.DnsService.targets', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=1033,
)

_DNSTABLE_DNSSERVICELIST = _descriptor.Descriptor(
  name='DnsServiceList',
  full_name='envoy.data.dns.v3.DnsTable.DnsServiceList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='services', full_name='envoy.data.dns.v3.DnsTable.DnsServiceList.services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1119,
)

_DNSTABLE_DNSENDPOINT = _descriptor.Descriptor(
  name='DnsEndpoint',
  full_name='envoy.data.dns.v3.DnsTable.DnsEndpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_list', full_name='envoy.data.dns.v3.DnsTable.DnsEndpoint.address_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.data.dns.v3.DnsTable.DnsEndpoint.cluster_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_list', full_name='envoy.data.dns.v3.DnsTable.DnsEndpoint.service_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.data.dns.v2alpha.DnsTable.DnsEndpoint',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='endpoint_config', full_name='envoy.data.dns.v3.DnsTable.DnsEndpoint.endpoint_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1122,
  serialized_end=1368,
)

_DNSTABLE_DNSVIRTUALDOMAIN = _descriptor.Descriptor(
  name='DnsVirtualDomain',
  full_name='envoy.data.dns.v3.DnsTable.DnsVirtualDomain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.data.dns.v3.DnsTable.DnsVirtualDomain.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\300\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='envoy.data.dns.v3.DnsTable.DnsVirtualDomain.endpoint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer_ttl', full_name='envoy.data.dns.v3.DnsTable.DnsVirtualDomain.answer_ttl', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\0042\002\010\036', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.data.dns.v2alpha.DnsTable.DnsVirtualDomain',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1371,
  serialized_end=1590,
)

_DNSTABLE = _descriptor.Descriptor(
  name='DnsTable',
  full_name='envoy.data.dns.v3.DnsTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_retry_count', full_name='envoy.data.dns.v3.DnsTable.external_retry_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_domains', full_name='envoy.data.dns.v3.DnsTable.virtual_domains', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='known_suffixes', full_name='envoy.data.dns.v3.DnsTable.known_suffixes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DNSTABLE_ADDRESSLIST, _DNSTABLE_DNSSERVICEPROTOCOL, _DNSTABLE_DNSSERVICETARGET, _DNSTABLE_DNSSERVICE, _DNSTABLE_DNSSERVICELIST, _DNSTABLE_DNSENDPOINT, _DNSTABLE_DNSVIRTUALDOMAIN, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.data.dns.v2alpha.DnsTable',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=1630,
)

_DNSTABLE_ADDRESSLIST.containing_type = _DNSTABLE
_DNSTABLE_DNSSERVICEPROTOCOL.containing_type = _DNSTABLE
_DNSTABLE_DNSSERVICEPROTOCOL.oneofs_by_name['protocol_config'].fields.append(
  _DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['number'])
_DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['number'].containing_oneof = _DNSTABLE_DNSSERVICEPROTOCOL.oneofs_by_name['protocol_config']
_DNSTABLE_DNSSERVICEPROTOCOL.oneofs_by_name['protocol_config'].fields.append(
  _DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['name'])
_DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['name'].containing_oneof = _DNSTABLE_DNSSERVICEPROTOCOL.oneofs_by_name['protocol_config']
_DNSTABLE_DNSSERVICETARGET.containing_type = _DNSTABLE
_DNSTABLE_DNSSERVICETARGET.oneofs_by_name['endpoint_type'].fields.append(
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['host_name'])
_DNSTABLE_DNSSERVICETARGET.fields_by_name['host_name'].containing_oneof = _DNSTABLE_DNSSERVICETARGET.oneofs_by_name['endpoint_type']
_DNSTABLE_DNSSERVICETARGET.oneofs_by_name['endpoint_type'].fields.append(
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['cluster_name'])
_DNSTABLE_DNSSERVICETARGET.fields_by_name['cluster_name'].containing_oneof = _DNSTABLE_DNSSERVICETARGET.oneofs_by_name['endpoint_type']
_DNSTABLE_DNSSERVICE.fields_by_name['protocol'].message_type = _DNSTABLE_DNSSERVICEPROTOCOL
_DNSTABLE_DNSSERVICE.fields_by_name['ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DNSTABLE_DNSSERVICE.fields_by_name['targets'].message_type = _DNSTABLE_DNSSERVICETARGET
_DNSTABLE_DNSSERVICE.containing_type = _DNSTABLE
_DNSTABLE_DNSSERVICELIST.fields_by_name['services'].message_type = _DNSTABLE_DNSSERVICE
_DNSTABLE_DNSSERVICELIST.containing_type = _DNSTABLE
_DNSTABLE_DNSENDPOINT.fields_by_name['address_list'].message_type = _DNSTABLE_ADDRESSLIST
_DNSTABLE_DNSENDPOINT.fields_by_name['service_list'].message_type = _DNSTABLE_DNSSERVICELIST
_DNSTABLE_DNSENDPOINT.containing_type = _DNSTABLE
_DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config'].fields.append(
  _DNSTABLE_DNSENDPOINT.fields_by_name['address_list'])
_DNSTABLE_DNSENDPOINT.fields_by_name['address_list'].containing_oneof = _DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config']
_DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config'].fields.append(
  _DNSTABLE_DNSENDPOINT.fields_by_name['cluster_name'])
_DNSTABLE_DNSENDPOINT.fields_by_name['cluster_name'].containing_oneof = _DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config']
_DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config'].fields.append(
  _DNSTABLE_DNSENDPOINT.fields_by_name['service_list'])
_DNSTABLE_DNSENDPOINT.fields_by_name['service_list'].containing_oneof = _DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config']
_DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['endpoint'].message_type = _DNSTABLE_DNSENDPOINT
_DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['answer_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DNSTABLE_DNSVIRTUALDOMAIN.containing_type = _DNSTABLE
_DNSTABLE.fields_by_name['virtual_domains'].message_type = _DNSTABLE_DNSVIRTUALDOMAIN
_DNSTABLE.fields_by_name['known_suffixes'].message_type = envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2._STRINGMATCHER
DESCRIPTOR.message_types_by_name['DnsTable'] = _DNSTABLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DnsTable = _reflection.GeneratedProtocolMessageType('DnsTable', (_message.Message,), {

  'AddressList' : _reflection.GeneratedProtocolMessageType('AddressList', (_message.Message,), {
    'DESCRIPTOR' : _DNSTABLE_ADDRESSLIST,
    '__module__' : 'envoy.data.dns.v3.dns_table_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.dns.v3.DnsTable.AddressList)
    })
  ,

  'DnsServiceProtocol' : _reflection.GeneratedProtocolMessageType('DnsServiceProtocol', (_message.Message,), {
    'DESCRIPTOR' : _DNSTABLE_DNSSERVICEPROTOCOL,
    '__module__' : 'envoy.data.dns.v3.dns_table_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.dns.v3.DnsTable.DnsServiceProtocol)
    })
  ,

  'DnsServiceTarget' : _reflection.GeneratedProtocolMessageType('DnsServiceTarget', (_message.Message,), {
    'DESCRIPTOR' : _DNSTABLE_DNSSERVICETARGET,
    '__module__' : 'envoy.data.dns.v3.dns_table_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.dns.v3.DnsTable.DnsServiceTarget)
    })
  ,

  'DnsService' : _reflection.GeneratedProtocolMessageType('DnsService', (_message.Message,), {
    'DESCRIPTOR' : _DNSTABLE_DNSSERVICE,
    '__module__' : 'envoy.data.dns.v3.dns_table_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.dns.v3.DnsTable.DnsService)
    })
  ,

  'DnsServiceList' : _reflection.GeneratedProtocolMessageType('DnsServiceList', (_message.Message,), {
    'DESCRIPTOR' : _DNSTABLE_DNSSERVICELIST,
    '__module__' : 'envoy.data.dns.v3.dns_table_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.dns.v3.DnsTable.DnsServiceList)
    })
  ,

  'DnsEndpoint' : _reflection.GeneratedProtocolMessageType('DnsEndpoint', (_message.Message,), {
    'DESCRIPTOR' : _DNSTABLE_DNSENDPOINT,
    '__module__' : 'envoy.data.dns.v3.dns_table_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.dns.v3.DnsTable.DnsEndpoint)
    })
  ,

  'DnsVirtualDomain' : _reflection.GeneratedProtocolMessageType('DnsVirtualDomain', (_message.Message,), {
    'DESCRIPTOR' : _DNSTABLE_DNSVIRTUALDOMAIN,
    '__module__' : 'envoy.data.dns.v3.dns_table_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.dns.v3.DnsTable.DnsVirtualDomain)
    })
  ,
  'DESCRIPTOR' : _DNSTABLE,
  '__module__' : 'envoy.data.dns.v3.dns_table_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.dns.v3.DnsTable)
  })
_sym_db.RegisterMessage(DnsTable)
_sym_db.RegisterMessage(DnsTable.AddressList)
_sym_db.RegisterMessage(DnsTable.DnsServiceProtocol)
_sym_db.RegisterMessage(DnsTable.DnsServiceTarget)
_sym_db.RegisterMessage(DnsTable.DnsService)
_sym_db.RegisterMessage(DnsTable.DnsServiceList)
_sym_db.RegisterMessage(DnsTable.DnsEndpoint)
_sym_db.RegisterMessage(DnsTable.DnsVirtualDomain)


DESCRIPTOR._options = None
_DNSTABLE_ADDRESSLIST.fields_by_name['address']._options = None
_DNSTABLE_ADDRESSLIST._options = None
_DNSTABLE_DNSSERVICEPROTOCOL.oneofs_by_name['protocol_config']._options = None
_DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['number']._options = None
_DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['name']._options = None
_DNSTABLE_DNSSERVICETARGET.oneofs_by_name['endpoint_type']._options = None
_DNSTABLE_DNSSERVICETARGET.fields_by_name['host_name']._options = None
_DNSTABLE_DNSSERVICETARGET.fields_by_name['cluster_name']._options = None
_DNSTABLE_DNSSERVICETARGET.fields_by_name['priority']._options = None
_DNSTABLE_DNSSERVICETARGET.fields_by_name['weight']._options = None
_DNSTABLE_DNSSERVICETARGET.fields_by_name['port']._options = None
_DNSTABLE_DNSSERVICE.fields_by_name['service_name']._options = None
_DNSTABLE_DNSSERVICE.fields_by_name['ttl']._options = None
_DNSTABLE_DNSSERVICE.fields_by_name['targets']._options = None
_DNSTABLE_DNSSERVICELIST.fields_by_name['services']._options = None
_DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config']._options = None
_DNSTABLE_DNSENDPOINT._options = None
_DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['name']._options = None
_DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['answer_ttl']._options = None
_DNSTABLE_DNSVIRTUALDOMAIN._options = None
_DNSTABLE.fields_by_name['external_retry_count']._options = None
_DNSTABLE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/metrics/v2/metrics_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/metrics/v2/metrics_service.proto',
  package='envoy.config.metrics.v2',
  syntax='proto3',
  serialized_options=b'\n%io.envoyproxy.envoy.config.metrics.v2B\023MetricsServiceProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-envoy/config/metrics/v2/metrics_service.proto\x12\x17\x65nvoy.config.metrics.v2\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"V\n\x14MetricsServiceConfig\x12>\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\x46\n%io.envoyproxy.envoy.config.metrics.v2B\x13MetricsServiceProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_METRICSSERVICECONFIG = _descriptor.Descriptor(
  name='MetricsServiceConfig',
  full_name='envoy.config.metrics.v2.MetricsServiceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.metrics.v2.MetricsServiceConfig.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=254,
)

_METRICSSERVICECONFIG.fields_by_name['grpc_service'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2._GRPCSERVICE
DESCRIPTOR.message_types_by_name['MetricsServiceConfig'] = _METRICSSERVICECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MetricsServiceConfig = _reflection.GeneratedProtocolMessageType('MetricsServiceConfig', (_message.Message,), {
  'DESCRIPTOR' : _METRICSSERVICECONFIG,
  '__module__' : 'envoy.config.metrics.v2.metrics_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.metrics.v2.MetricsServiceConfig)
  })
_sym_db.RegisterMessage(MetricsServiceConfig)


DESCRIPTOR._options = None
_METRICSSERVICECONFIG.fields_by_name['grpc_service']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/rate_limit_descriptors/expr/v3/expr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/rate_limit_descriptors/expr/v3/expr.proto',
  package='envoy.extensions.rate_limit_descriptors.expr.v3',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.rate_limit_descriptors.expr.v3B\tExprProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:envoy/extensions/rate_limit_descriptors/expr/v3/expr.proto\x12/envoy.extensions.rate_limit_descriptors.expr.v3\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa1\x01\n\nDescriptor\x12\x1f\n\x0e\x64\x65scriptor_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\rskip_if_error\x18\x02 \x01(\x08\x12\x17\n\x04text\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x30\n\x06parsed\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprH\x00\x42\x10\n\x0e\x65xpr_specifierBT\n=io.envoyproxy.envoy.extensions.rate_limit_descriptors.expr.v3B\tExprProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_DESCRIPTOR = _descriptor.Descriptor(
  name='Descriptor',
  full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptor_key', full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor.descriptor_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_if_error', full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor.skip_if_error', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parsed', full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor.parsed', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='expr_specifier', full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor.expr_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=207,
  serialized_end=368,
)

_DESCRIPTOR.fields_by_name['parsed'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._EXPR
_DESCRIPTOR.oneofs_by_name['expr_specifier'].fields.append(
  _DESCRIPTOR.fields_by_name['text'])
_DESCRIPTOR.fields_by_name['text'].containing_oneof = _DESCRIPTOR.oneofs_by_name['expr_specifier']
_DESCRIPTOR.oneofs_by_name['expr_specifier'].fields.append(
  _DESCRIPTOR.fields_by_name['parsed'])
_DESCRIPTOR.fields_by_name['parsed'].containing_oneof = _DESCRIPTOR.oneofs_by_name['expr_specifier']
DESCRIPTOR.message_types_by_name['Descriptor'] = _DESCRIPTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Descriptor = _reflection.GeneratedProtocolMessageType('Descriptor', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIPTOR,
  '__module__' : 'envoy.extensions.rate_limit_descriptors.expr.v3.expr_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor)
  })
_sym_db.RegisterMessage(Descriptor)


DESCRIPTOR._options = None
_DESCRIPTOR.fields_by_name['descriptor_key']._options = None
_DESCRIPTOR.fields_by_name['text']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/grpc_method_list.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/core/grpc_method_list.proto',
  package='envoy.api.v2.core',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.api.v2.coreB\023GrpcMethodListProtoP\001\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(envoy/api/v2/core/grpc_method_list.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8f\x01\n\x0eGrpcMethodList\x12;\n\x08services\x18\x01 \x03(\x0b\x32).envoy.api.v2.core.GrpcMethodList.Service\x1a@\n\x07Service\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1e\n\x0cmethod_names\x18\x02 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\\\n\x1fio.envoyproxy.envoy.api.v2.coreB\x13GrpcMethodListProtoP\x01\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_GRPCMETHODLIST_SERVICE = _descriptor.Descriptor(
  name='Service',
  full_name='envoy.api.v2.core.GrpcMethodList.Service',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.api.v2.core.GrpcMethodList.Service.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method_names', full_name='envoy.api.v2.core.GrpcMethodList.Service.method_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=295,
)

_GRPCMETHODLIST = _descriptor.Descriptor(
  name='GrpcMethodList',
  full_name='envoy.api.v2.core.GrpcMethodList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='services', full_name='envoy.api.v2.core.GrpcMethodList.services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRPCMETHODLIST_SERVICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=295,
)

_GRPCMETHODLIST_SERVICE.containing_type = _GRPCMETHODLIST
_GRPCMETHODLIST.fields_by_name['services'].message_type = _GRPCMETHODLIST_SERVICE
DESCRIPTOR.message_types_by_name['GrpcMethodList'] = _GRPCMETHODLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GrpcMethodList = _reflection.GeneratedProtocolMessageType('GrpcMethodList', (_message.Message,), {

  'Service' : _reflection.GeneratedProtocolMessageType('Service', (_message.Message,), {
    'DESCRIPTOR' : _GRPCMETHODLIST_SERVICE,
    '__module__' : 'envoy.api.v2.core.grpc_method_list_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcMethodList.Service)
    })
  ,
  'DESCRIPTOR' : _GRPCMETHODLIST,
  '__module__' : 'envoy.api.v2.core.grpc_method_list_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcMethodList)
  })
_sym_db.RegisterMessage(GrpcMethodList)
_sym_db.RegisterMessage(GrpcMethodList.Service)


DESCRIPTOR._options = None
_GRPCMETHODLIST_SERVICE.fields_by_name['name']._options = None
_GRPCMETHODLIST_SERVICE.fields_by_name['method_names']._options = None
# @@protoc_insertion_point(module_scope)
